@@ -5,14 +5,17 @@ Module concerned with alignment of diffraction images
 """
 from functools import partial
 
+from os import cpu_count
 import numpy as np
 from warnings import warn
 from npstreams import array_stream
 from scipy import ndimage as ndi
+from ..fft import with_skued_fft
 from skimage.registration import phase_cross_correlation
 
 
 @array_stream
+@with_skued_fft
 def itrack_peak(images, row_slice=None, col_slice=None, precision=1 / 10):
     """
     Generator function that tracks a diffraction peak in a stream of images.
@@ -50,9 +53,13 @@ def itrack_peak(images, row_slice=None, col_slice=None, precision=1 / 10):
     ref = np.array(first[row_slice, col_slice], copy=True)
     sub = np.empty_like(ref)
 
+    # scikit-image will use scipy.fft module
+    # so we can increase the number of FFT workers
+    # to get a performance speedup (50% in my tests)
     for image in images:
         sub[:] = image[row_slice, col_slice]
-        shift = phase_cross_correlation(
+
+        shift = with_skued_fft(phase_cross_correlation)(
             reference_image=ref,
             moving_image=sub,
             return_error=False,
@@ -85,7 +92,7 @@ def align(image, reference, mask=None, fill_value=0.0):
     --------
     ialign : generator of aligned images
     """
-    shift = phase_cross_correlation(
+    shift = with_skued_fft(phase_cross_correlation)(
         reference_image=reference,
         moving_image=image,
         reference_mask=mask,
