@@ -12,7 +12,7 @@ MAX_INV_ANG = 5.5
 
 
 def diff_pattern_sc():
-    """ Simulate a single-crystal diffraction pattern """
+    """Simulate a single-crystal diffraction pattern"""
     cryst = Crystal.from_database("C")
     rr, cc = np.indices((DIFF_PATTERN_SIZE, DIFF_PATTERN_SIZE))
     rr -= rr.shape[1] // 2
@@ -27,11 +27,12 @@ def diff_pattern_sc():
     gaussian_filter(I, sigma=1, output=I)
     I = np.minimum(I, 0.8 * I.max())
     I /= I.max()
+    I += 0.05 * np.random.random(size=I.shape)
     return kx, ky, I, cryst
 
 
 def test_bragg_peaks():
-    """ Test that the `bragg_peaks` function finds all Bragg peaks. """
+    """Test that the `bragg_peaks` function finds all Bragg peaks."""
     kx, ky, I, cryst = diff_pattern_sc()
     kk = np.sqrt(kx ** 2 + ky ** 2)
 
@@ -40,11 +41,7 @@ def test_bragg_peaks():
     in_plane_refls = [
         refl
         for refl in cryst.bounded_reflections(kk.max())
-        if (
-            refl[2] == 0
-            and np.linalg.norm(refl) > 0
-            and np.abs(cryst.scattering_vector(refl)[0]) < kx.max()
-        )
+        if (refl[2] == 0 and np.abs(cryst.scattering_vector(refl)[0]) < kx.max())
     ]
 
     peaks = bragg_peaks(I, mask=np.ones_like(I, dtype=bool))
