@@ -56,7 +56,7 @@ def kinematicsim(crystal, kx, ky, energy=90):
     transmission_function = np.exp(1j * interaction_parameter(energy) * potential)
 
     exit_wave = fft.ifft2(
-        fft.fft2(np.ones_like(xx, dtype=np.complex) * transmission_function)
+        fft.fft2(np.ones_like(xx, dtype=complex) * transmission_function)
     )
     intensity = fft.fftshift(np.abs(fft.fft2(exit_wave)) ** 2)
 
